@@ -4,6 +4,7 @@ from .emission_track import (
     set_params,
     get_params,
     track,
+    define_carbon_index,
     calculate_money,
     summary,
 )
@@ -16,4 +17,8 @@ from eco2ai.tools.tools_cpu import (
 from eco2ai.tools.tools_gpu import (
     GPU,
     all_available_gpu
+)
+
+from eco2ai.tools.tools_ram import (
+    RAM,
 )
\ No newline at end of file
